@@ -1,4 +1,4 @@
-use surf::StatusCode;
+use surf::{Client, Config, StatusCode};
 use thiserror::Error;
 
 #[derive(Debug, Error)]
@@ -12,3 +12,9 @@ pub enum RequestError {
   #[error("Unexpected status code {0}. Response body: {1}")]
   UnexpectedStatusCode(StatusCode, String),
 }
+
+#[derive(Debug, Error)]
+pub enum ClientError {
+  #[error("Failed to create client")]
+  FailedCreate(<Client as TryFrom<Config>>::Error),
+}
