@@ -3,11 +3,13 @@ mod errors;
 mod middleware;
 
 pub use deals::{Deals, DealsScope};
+pub use errors::{ClientError, RequestError};
 pub use three_commas_types::{Bot, BotStats, Deal, Pair};
 
 use middleware::RequestBuilderExt;
+use std::result::Result as StdResult;
 use std::time::Duration;
-use surf::{http::Result, Client, Url};
+use surf::{http::Result, Client, Config, Url};
 
 #[derive(Clone)]
 pub struct ThreeCommasClient {
@@ -15,8 +17,13 @@ pub struct ThreeCommasClient {
 }
 
 impl ThreeCommasClient {
-  pub fn new(api_key: impl AsRef<str>, secret: impl AsRef<str>) -> Self {
-    let mut client = Client::new()
+  pub fn new(api_key: impl AsRef<str>, secret: impl AsRef<str>) -> StdResult<Self, ClientError> {
+    let client: Client = Config::new()
+      .set_base_url(Url::parse("https://api.3commas.io/public/api/").unwrap())
+      .try_into()
+      .map_err(ClientError::FailedCreate)?;
+
+    let client = client
       .with(middleware::TracingRequestLoggerMiddlware)
       .with(middleware::ApiKeyMiddleware::new(api_key.as_ref()))
       .with(middleware::SigningMiddleware::new(secret.as_ref()))
@@ -24,9 +31,8 @@ impl ThreeCommasClient {
       .with(middleware::Limit::new(2, Duration::from_secs(1)))
       .with(middleware::Limit::new(30, Duration::from_secs(60)))
       .with(middleware::TracingPipelineLoggerMiddlware);
-    client.set_base_url(Url::parse("https://api.3commas.io/public/api/").unwrap());
 
-    Self { client }
+    Ok(Self { client })
   }
 
   pub async fn bots(&self) -> Result<Vec<Bot>> {
